
rattail_corepos
===============

Rattail is a retail software framework, released under the GNU General Public
License.

This package contains software interfaces for the `CORE POS`_ system.

.. _`CORE POS`: https://github.com/CORE-POS/IS4C

Please see Rattail's `home page`_ for more information.

.. _`home page`: https://rattailproject.org/
